You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by de...@apache.org on 2005/04/19 07:47:35 UTC

svn commit: r161847 - webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java

Author: deepal
Date: Mon Apr 18 22:47:34 2005
New Revision: 161847

URL: http://svn.apache.org/viewcvs?view=rev&rev=161847
Log: (empty)


Modified:
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java?view=diff&r1=161846&r2=161847
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java Mon Apr 18 22:47:34 2005
@@ -102,7 +102,7 @@
      */
 
     public DeploymentEngine(String RepositaryName) throws DeploymentException {
-        this(RepositaryName, "axisGlobal.xml");
+        this(RepositaryName, "server.xml");
     }
 
     /**
@@ -128,7 +128,7 @@
         File serverConf = new File(repository, serverXMLFile);
         if (!serverConf.exists()) {
             ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/axisGlobal.xml");
+            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/server.xml");
             if (in != null) {
                 try {
                     serverConf.createNewFile();
@@ -147,7 +147,7 @@
 
 
             } else {
-                throw new DeploymentException("can not found org/apache/axis/deployment/axisGlobal.xml");
+                throw new DeploymentException("can not found org/apache/axis/deployment/server.xml");
 
             }
         }
@@ -221,7 +221,7 @@
     }
 
     /**
      * This methode used to check the modules referd by axisGlobal.xml
      * are exist , or they have deployed
      */
     private void validateServerModule() throws AxisFault{
@@ -221,7 +221,7 @@
 
     /**
-     * This methode used to check the modules referd by axisGlobal.xml
+     * This methode used to check the modules referd by server.xml
      * are exist , or they have deployed
      */